@@ -4,7 +4,7 @@
 #'
 #' @param dois Search by a single DOI or many DOIs.
 #' @param format Name of the format. One of "rdf-xml", "turtle", "citeproc-json", "text", 
-#' "ris", "bibtex", "crossref-xml", "datacite-xml", or "bibentry"
+#' "ris", "bibtex", "crossref-xml", "datacite-xml","bibentry", or "crossref-tdm"
 #' @param style a CSL style (for text format only). See \code{\link{get_styles}} 
 #' for options. Default: apa. If there's a style that CrossRef doesn't support you'll get a 
 #' \code{(500) Internal Server Error}
@@ -13,12 +13,8 @@
 #' @details See \url{http://www.crosscite.org/cn/} for more info on the
 #'   	Crossref Content Negotiation API service.
 #'
-#' @examples
-#' \donttest{
+#' @examples \dontrun{
 #' cr_cn(dois="10.1126/science.169.3946.635")
-#' }
-#' 
-#' \dontrun{
 #' cr_cn(dois="10.1126/science.169.3946.635", format="citeproc-json")
 #' cr_cn("10.1126/science.169.3946.635", "rdf-xml")
 #' cr_cn("10.1126/science.169.3946.635", "crossref-xml")
@@ -40,7 +36,6 @@
 #' dois <- cr_r(2)
 #' cr_cn(dois, "text", "apa")
 #' 
-#' \dontrun{
 #' # Cycle through random styles - print style on each try
 #' stys <- get_styles()
 #' foo <- function(x){
@@ -48,15 +43,13 @@
 #'  cr_cn("10.1126/science.169.3946.635", "text", style=x)
 #' }
 #' foo(sample(stys, 1))
-#'
-#' }
 #' }
 
 `cr_cn` <- function(dois, format = "text", style = 'apa', locale = "en-US", .progress="none", ...){
   format <- match.arg(format, c("rdf-xml", "turtle", "citeproc-json",
                                 "text", "ris", "bibtex", "crossref-xml",
-                                "datacite-xml", "bibentry"))
-  cn <- function(doi){
+                                "datacite-xml", "bibentry", "crossref-tdm"))
+  cn <- function(doi, ...){
     url <- paste("http://dx.doi.org", doi, sep="/")
     pick <- c(
            "rdf-xml" = "application/rdf+xml",
@@ -67,11 +60,12 @@
            "bibtex" = "application/x-bibtex",
            "crossref-xml" = "application/vnd.crossref.unixref+xml",
            "datacite-xml" = "application/vnd.datacite.datacite+xml",
-           "bibentry" = "application/x-bibtex")
+           "bibentry" = "application/x-bibtex",
+           "crossref-tdm" = "application/vnd.crossref.unixsd+xml")
     type <- pick[[format]]
     if(format == "text")
       type <- paste(type, "; style = ", style, "; locale = ", locale, sep="")
-    response <- GET(url, add_headers(Accept = type, followlocation = TRUE), ...)
+    response <- GET(url, ..., add_headers(Accept = type, followlocation = TRUE))
     stop_for_status(response)
     select <- c(
            "rdf-xml" = "text/xml",
@@ -82,7 +76,8 @@
            "bibtex" = "text/plain",
            "crossref-xml" = "text/xml",
            "datacite-xml" = "text/xml",
-           "bibentry" = "text/plain")
+           "bibentry" = "text/plain",
+           "crossref-tdm" = "text/xml")
     parser <- select[[format]]
     out <- content(response, "parsed", parser, "UTF-8")
     if(format == "text")
@@ -93,8 +88,8 @@
   }
 
   if(length(dois) > 1)
-    llply(dois, function(z) {
-      out = try(cn(z), silent=TRUE)
+    llply(dois, function(z, ...) {
+      out = try(cn(z, ...), silent=TRUE)
       if("try-error" %in% class(out)) {
         warning(paste0("Failure in resolving '", z, "'. See error detail in results."))
         out <- list(doi=z, error=out[[1]])
@@ -102,7 +97,7 @@
       return(out)
     }, .progress=.progress)
   else
-    cn(dois)
+    cn(dois, ...)
 }
 
 #' @import bibtex
