@@ -25,12 +25,8 @@
 #' a certain organisaton, member IDs and the member routes should be used.
 #'
 #' @references \url{https://github.com/CrossRef/rest-api-doc/blob/master/rest_api.md}
-#' @examples 
-#' \donttest{
+#' @examples \dontrun{
 #' cr_prefixes(prefixes="10.1016")
-#' }
-#' 
-#' \dontrun{
 #' cr_prefixes(prefixes="10.1016", works=TRUE)
 #' cr_prefixes(prefixes=c('10.1016','10.1371','10.1023','10.4176','10.1093'))
 #' cr_prefixes(prefixes=c('10.1016','10.1371'), works=TRUE)
@@ -59,7 +55,7 @@
   if(length(prefixes) > 1){
     res <- llply(prefixes, prefixes_GET, args=args, works=works, ..., .progress=.progress)
     out <- lapply(res, "[[", "message")
-    out <- if(works) do.call(c, lapply(out, function(x) lapply(x$items, parse_works))) else lapply(out, data.frame, stringsAsFactors=FALSE)
+    out <- if(works) do.call(c, lapply(out, function(x) lapply(x$items, parse_works))) else lapply(out, DataFrame)
     df <- rbind_all(out)
     meta <- if(works) data.frame(prefix=prefixes, do.call(rbind, lapply(res, parse_meta)), stringsAsFactors = FALSE) else NULL
     if(facet_log){ 
@@ -70,7 +66,7 @@
     list(meta=meta, data=df, facets=ft)
   } else {
     tmp <- prefixes_GET(prefixes, args, works=works, ...)
-    out <- if(works) rbind_all(lapply(tmp$message$items, parse_works)) else data.frame(tmp$message, stringsAsFactors=FALSE)
+    out <- if(works) rbind_all(lapply(tmp$message$items, parse_works)) else DataFrame(tmp$message)
     meta <- if(works) data.frame(prefix=prefixes, parse_meta(tmp), stringsAsFactors = FALSE) else NULL
     list(meta=meta, data=out, facets=parse_facets(tmp$message$facets))
   }
@@ -80,3 +76,8 @@ prefixes_GET <- function(x, args, works, ...){
   path <- if(works) sprintf("prefixes/%s/works", x) else sprintf("prefixes/%s", x)
   cr_GET(path, args, todf = FALSE, ...)
 }
+
+DataFrame <- function(x){
+  x[ sapply(x, function(y) if(is.null(y) || length(y) == 0) TRUE else FALSE)] <- NA
+  data.frame(x, stringsAsFactors = FALSE)
+}
