@@ -1,7 +1,7 @@
 context("testing cr_agency")
 
 test_that("cr_ageny returns correct class", {
-	 expect_is(cr_agency(dois = '10.13039/100000001'), "list")
+	 expect_is(cr_agency(dois = '10.1038/jid.2009.428'), "list")
    expect_is(cr_agency(dois = c('10.13039/100000001','10.13039/100000015')), "list")
 })
 
@@ -11,5 +11,5 @@ test_that("cr_ageny returns correct length", {
 
 test_that("cr_ageny fails correctly", {
   library('httr')
-  expect_error(cr_agency(dois = '10.13039/100000001', config=timeout(0.001)))
+  expect_error(cr_agency(dois = cr_r(3), config=timeout(0.01)))
 })
